Client

Struct Client 

pub struct Client { /* private fields */ }
A connected client that can be used to send messages to the server.

Example

 let Some(client) = connect(DummyConnector, DummyHandler).await else {
    log::info!("Failed to connect");
    return;
 };
  
 client.text("hello world").await.unwrap();

Implementations

Source

impl Client

pub async fn text( &self, message: impl Into<String>, ) -> Result<(), SendError<Message>>

Send a text message to the server.

Errors

Returns an Error if all receivers have been dropped.

pub fn blocking_text( &self, message: impl Into<String>, ) -> Result<(), SendError<Message>>

Send a text message to the server.

Errors

Returns an Error if all receivers have been dropped.

pub fn blocking_text_timeout( &self, message: impl Into<String>, timeout: Duration, ) -> Result<(), SendTimeoutError<Message>>

Send a text message to the server allowing to set up a timeout.

Errors

Returns an Error if all receivers have been dropped or the timeout has been reached.

pub async fn binary( &self, message: impl IntoIterator<Item = u8>, ) -> Result<(), SendError<Message>>

Send a binary message to the server.

Errors

Returns an Error if all receivers have been dropped.

pub fn blocking_binary( &self, message: impl IntoIterator<Item = u8>, ) -> Result<(), SendError<Message>>

Send a binary message to the server.

Errors

Returns an Error if all receivers have been dropped.

pub fn blocking_binary_timeout( &self, message: impl IntoIterator<Item = u8>, timeout: Duration, ) -> Result<(), SendTimeoutError<Message>>

Send a binary message to the server.

Errors

Returns an Error if all receivers have been dropped or the timeout has been reached.

pub async fn force_reconnect(&self) -> Result<(), SendError<Command>>

Force the socket to reconnect, this can be useful when server address can change.

Errors

Return an Error if the receiver is dropped.

pub fn blocking_force_reconnect(&self) -> Result<(), SendError<Command>>

Force the socket to reconnect, this can be useful when server address can change.

Errors

Return an Error if the receiver is dropped.

pub fn blocking_force_reconnect_timeout( &self, timeout: Duration, ) -> Result<(), SendTimeoutError<Command>>

Force the socket to reconnect, this can be useful when server address can change.

Errors

Return an Error if the receiver is dropped.

pub async fn close(&self) -> Result<()>

Allow the Client to close the connection.

This will also stop any background task to avoid any reconnection.

Errors

Return an Error if the receiver is dropped.

pub fn blocking_close(self) -> Result<()>

Allow the Client to close the connection.

This will also stop any background task to avoid any reconnection.

Errors

Return an Error if the receiver is dropped.

pub fn blocking_close_timeout( self, request_timeout: Duration, confirmation_timeout: Duration, ) -> Result<()>

Allow the Client to close the connection.

This will also stop any background task to avoid any reconnection.

Errors

Return an Error if the receiver is dropped.